@@ -46,12 +46,21 @@ def _get_figure_and_axis():
 
 
 def _set_ticks(xmin, xmax, ymin, ymax):
-    xticks = list(np.arange(xmin + 1, xmax, 1))
+    n_step = 1
+    xticks = list(np.arange(xmin + 1, xmax, n_step))
+    while len(xticks) > 10:
+        n_step *= 2
+        xticks = list(np.arange(xmin + 1, xmax, n_step))
+
     if 0 in xticks:
         xticks.remove(0)
     plt.xticks(xticks, fontsize=16)
 
-    yticks = list(np.arange(ymin + 1, ymax, 1))
+    n_step = 1
+    yticks = list(np.arange(ymin + 1, ymax, n_step))
+    while len(yticks) > 10:
+        n_step *= 2
+        yticks = list(np.arange(ymin + 1, ymax, n_step))
     if 0 in yticks:
         yticks.remove(0)
     plt.yticks(yticks, fontsize=16)
